Purpose
=======

This documentation is to ensure the users are empowered to unlock the most possible value from ``auxi-mpp``, by providing them with a clear guide on what it has to offer and how to use it.